import React, { useState, useEffect } from 'react';
import {
  Form,
  Modal,
  Space,
  Table,
  Button,
  Popconfirm,
  Spin,
  notification,
} from 'antd';

import { reloadTableFields, removeFields } from '@/services/platform/bs';
import FieldEditor from './fieldEditor';

const AddModal = props => {
  const [tableData, setTableData] = useState([]);
  const { callBackSubmit = () => {}, type, formObj, visible } = props;
  const [loading, setLoading] = useState(false);
  const [treeLoading, setTreeLoading] = useState(true);
  const [form] = Form.useForm();
  const [flag, setFlag] = useState(0); // 弹窗类型
  const [isVisible, setIsVisible] = useState(false); // 弹窗
  const [isType, setIsType] = useState(''); // 弹窗类型
  const [itemData, setItemData] = useState({});
  const { Item } = Form;
  // 提交
  const onSubmit = () => {
    form.validateFields().then(validate => {
      if (validate) {
        setLoading(true);
        let obj = form.getFieldsValue();
      }
    });
  };
  const columns = [
    {
      title: '字段名',
      dataIndex: 'name',
      key: 'name',
      width: 150,
      render: text => <a>{text}</a>,
    },
    {
      title: '别名',
      dataIndex: 'alias',
      key: 'alias',
      align: 'center',
    },
    {
      title: '字段类型',
      dataIndex: 'storeType',
      key: 'storeType',
      align: 'center',
    },
    {
      title: '形态',
      dataIndex: 'shape',
      key: 'shape',
      align: 'center',
    },
    {
      title: '配置',
      dataIndex: 'config',
      key: 'config',
      align: 'center',
    },

    {
      title: '只读',
      dataIndex: 'readOnly',
      key: 'readOnly',
      align: 'center',
    },
    {
      title: '同步',
      dataIndex: 'syncEvent',
      key: 'syncEvent',
      align: 'center',
    },
    {
      title: '操作',
      width: 250,
      ellipsis: true,
      align: 'center',
      render: (text, record) => (
        <Space>
          <Button
            type="primary"
            size="small"
            onClick={() => {
              editor(record);
            }}
          >
            编辑
          </Button>
          <div onClick={e => e.stopPropagation()}>
            <Popconfirm
              title="是否删除该字段？"
              okText="确认"
              cancelText="取消"
              onConfirm={() => {
                deleteChart(record);
              }}
            >
              <Button size="small" danger>
                删除
              </Button>
            </Popconfirm>
          </div>
        </Space>
      ),
    },
  ];
  const editor = record => {
    setIsType('edit');
    setIsVisible(true);
    setItemData(record);
  };
  const Submit = prop => {
    setIsVisible(false);
    setFlag(flag + 1);
  };
  useEffect(() => {
    if (type !== '') {
      setTreeLoading(true);
      reloadTableFields({
        tableName: formObj.tableName,
      }).then(res => {
        setTreeLoading(false);
        if (res.msg === 'Ok') {
          setTableData(res.data.root);
        }
      });
    }
  }, [visible, flag]);

  // 删除表字段
  const deleteChart = record => {
    removeFields({ fieldIDs: record.ID }).then(res => {
      if (res.msg === 'Ok' || res.msg === '') {
        notification.success({
          message: '提示',
          duration: 3,
          description: '删除成功',
        });
        setFlag(flag + 1);
      } else {
        notification.error({
          message: '提示',
          duration: 3,
          description: res.msg,
        });
      }
    });
  };
  return (
    <>
      <Modal
        title="字段配置"
        bodyStyle={{ width: '100%', minHeight: '100px' }}
        style={{ top: '50px', left: '50px' }}
        width="60%"
        destroyOnClose
        maskClosable={false}
        cancelText="取消"
        okText="确认"
        {...props}
        onOk={() => onSubmit()}
        confirmLoading={loading}
        forceRender
        getContainer={false}
      >
        {visible && (
          <Spin tip="loading..." spinning={treeLoading}>
            <Table
              columns={columns}
              dataSource={tableData}
              // pagination={{ pageSize: 10 }}
              scroll={{ x: 'max-content', y: '35rem' }}
              size="small"
              rowKey={(record, index) => `complete${record.tableID}${index}`}
              pagination={false}
            />
          </Spin>
        )}
      </Modal>
      <FieldEditor
        isVisible={isVisible}
        isType={isType}
        itemData={itemData}
        formObj1={formObj}
        onCancel={() => setIsVisible(false)}
        callBackSubmit={Submit}
      />
    </>
  );
};
export default AddModal;
