import React, { useEffect, useState } from 'react'
import ReactHtmlParser from 'react-html-parser'
import {
    // Tree,
    Table,
    Space,
    Input,
    Button,
    Select,
    Popconfirm,
    notification,
    Spin,
    Tooltip
} from 'antd';
import { EditOutlined, DeleteOutlined, FontColorsOutlined, PlusSquareOutlined,SortDescendingOutlined } from '@ant-design/icons';
import PageContainer from '@/components/BasePageContainer';
import { CM_Table_LoadTable, removeTable, loadUnattachedTables } from '@/services/platform/bs'
import styles from './index.less'
import Editor from './components/Field/editor'
import AddTablelList from './components/Field/addTable'
import AffiliateAdd from './components/Field/affiliateAdd'
import FieldsConfig from './components/Field/fieldsConfig'
import LoadGroup from './components/Field/loadGroup'
const { Search } = Input;
const { Option } = Select;
const placeholder = "请输入表名"

const TableManager = () => {

    const [visible, setVisible] = useState(false); // 弹窗
    const [type, setType] = useState(''); // 弹窗类型
    const [formObj, setFormObj] = useState({});
    const [flag, setFlag] = useState(0); // 弹窗类型
    const [searchValue, setSearchValue] = useState('')
    const [treeLoading, setTreeLoading] = useState(true)
    const [tableList, setTableList] = useState([])
    const columns = [
        {
            title: '名称',
            dataIndex: 'tableName',
            key: 'tableName',
            width:300,
            render: text => <a>{text}</a>,

        },
        {
            title: '别名',
            dataIndex: 'tableAlias',
            key: 'tableAlias',
            align: 'center',
            width: 200,
        },
        {
            title: '表格样式',
            dataIndex: 'tableStyle',
            key: 'tableStyle',
            align: 'center',
            width: 150,
        },
        {
            title: '字段数量',
            dataIndex: 'fieldCount',
            key: 'fieldCount',
            align: 'center'
        },
        {
            title: '缺少字段',
            dataIndex: 'missingFieldCount',
            key: 'missingFieldCount',
            align: 'center',
            render: text => {
                let dom = ReactHtmlParser(text)
                return (<div>{dom}</div>)
            }
        },
        {
            title: '未附加',
            dataIndex: 'extraFieldCount',
            key: 'extraFieldCount',
            align: 'center'
        },
        {
            title: '分组数量',
            dataIndex: 'groupCount',
            key: 'groupCount',
            align: 'center'
        },
        {
            title: '操作',
            width: 250,
            ellipsis: true,
            align: 'center',
            render: (text, record) => (
                <Space>
                    <Tooltip title="修改">
                        <EditOutlined
                            onClick={() => changeDesc(record)}
                            style={{ fontSize: '20px', color: '#1890FF' }}
                        />
                    </Tooltip>
                    <Tooltip title="字段配置">
                        <FontColorsOutlined
                            onClick={() => fieldsConfig(record)}
                            style={{ fontSize: '16px', color: '#1890FF' }}
                        />
                    </Tooltip>
                    <Tooltip title="附加">
                        <PlusSquareOutlined
                            onClick={() => add(record)}
                            style={{ fontSize: '16px', color: '#1890FF' }}
                        />
                    </Tooltip>
                    <Tooltip title="分组与排序">
                        <SortDescendingOutlined
                            onClick={() => sort(record)}
                            style={{ fontSize: '16px', color: '#1890FF' }}
                        />
                    </Tooltip>
                    <div onClick={e => e.stopPropagation()}>
                        <Popconfirm
                            title="是否删除该表？"
                            okText="确认"
                            cancelText="取消"
                            onConfirm={() => {
                                deleteChart(record);
                            }}
                        >
                            <Tooltip title="删除">
                                <DeleteOutlined
                                    style={{ fontSize: '16px', color: '#e86060' }}
                                />
                            </Tooltip>
                        </Popconfirm>
                    </div>
                </Space>
            ),
        },

    ];
    const [tableData, setTableData] = useState([])

    useEffect((record) => {
        loadTable(searchValue)
        getField()
    }, [flag])

    //附加
    const add = (record) => {
        setFormObj(record);
        setType('affiliateAdd');
        setVisible(true);
    }
    //修改表名
    const changeDesc = (record) => {
        setType('edit');
        setVisible(true);
        setFormObj(record);
    }
    //删除表
    const deleteChart = (record) => {
        removeTable({ tableID: record.tableID, removeFields: true }).then(res => {
            if (res.msg === 'Ok' || res.msg === '') {
                notification.success({
                    message: '提示',
                    duration: 3,
                    description: '删除成功',
                });
                setFlag(flag + 1)
            }
            else {
                notification.error({
                    message: '提示',
                    duration: 3,
                    description: res.msg,
                });
            }
        })
    }
 
    const onSubmit = prop => {
        setVisible(false);
        setFlag(flag + 1)
    };
    //建表
    const AddTable = () => {
        setType('add');
        setVisible(true);
    }
    //附加表
    const AffiliateAddTable = () => {
        setType('affiliateAdd');
        setFormObj({});
        setVisible(true);
    }
    //字段配置
    const fieldsConfig = (record) => {
        setFormObj(record);
        setType('config');
        setVisible(true);
    }
    //分组与排序
    const sort = (record)=>{
        setFormObj(record);
        setType('sort');
        setVisible(true);
    }
    //搜索框改变时存储输入的值
    const handleChange = (e) => {
        setSearchValue(e.target.value)
    }
    //搜索
    const handleSearch = (text) => {
        loadTable(text)
        setSearchValue(text)
    }
    const getField = () => {
        loadUnattachedTables().then(res => {
            if (res.data.root && res.data.root.length) {
                setTableList(res.data.root)
            }

        })
    }
    //加载表
    const loadTable = (keyword) => {
        setTreeLoading(true)
        CM_Table_LoadTable({
            _version: 9999,
            filter: keyword || ''
        }).then(
            res => {
                setTreeLoading(false)
                if (res.msg === 'Ok') {
                    setTableData(res.data.root)
                }
            }
        )
    }
    return (
        <Spin tip="loading..." spinning={treeLoading}>
            <PageContainer>
                <div className={styles.tablemanager_container}>
                    <div className={styles.operate_bar}>
                        <div className={styles.fast_search}>
                            <div className={styles.title}>快速检索</div>
                            <Search
                                allowClear
                                placeholder={placeholder}
                                onSearch={handleSearch}
                                onChange={handleChange}
                                value={searchValue}
                                enterButton
                                style={{ width: "300px" }}
                            />
                        </div>

                        <Button type="primary" style={{ marginLeft: "10px" }} onClick={AddTable}>建表</Button>
                        <Button type="primary" style={{ marginLeft: "10px" }} onClick={AffiliateAddTable}>附加</Button>

                    </div>
                    <div className={styles.table_container}>
                        <Table
                            columns={columns}
                            dataSource={tableData}
                            //pagination={{ pageSize: 10 }}
                            scroll={{ x: 'max-content', y: 'calc(100vh - 228px)' }}
                            size="small"
                            style={{height:'8rem'}}
                            rowKey={(record, index) => `complete${record.tableID}${index}`}
                            pagination={{
                                showTotal: (total, range) =>
                                    `第${range[0]}-${range[1]} 条/共 ${total} 条`,
                                pageSizeOptions: [10, 20, 50, 100],
                                defaultPageSize: 20,
                                showQuickJumper: true,
                                showSizeChanger: true,
                            }}
                        />
                    </div>
                </div>

                {visible && type == 'edit' && (
                    <Editor
                        visible={visible}
                        onCancel={() => setVisible(false)}
                        callBackSubmit={onSubmit}
                        type={type}
                        formObj={formObj} />
                )}
                {visible && type === 'add' && (
                    <AddTablelList
                        type={type}
                        onCancel={() => setVisible(false)}
                        callBackSubmit={onSubmit}
                    />
                )}
                {visible && type === 'affiliateAdd' && (
                    <AffiliateAdd
                        visible={visible}
                        tableList={tableList}
                        type={type}
                        onCancel={() => setVisible(false)}
                        callBackSubmit={onSubmit}
                        formObj={formObj}
                    />
                )}
                {visible && type === 'config' && (
                    <FieldsConfig
                        visible={visible}
                        type={type}
                        formObj={formObj}
                        onCancel={() => setVisible(false)}
                        callBackSubmit={onSubmit}
                    />
                )}
                   {visible && type === 'sort' && (
                    <LoadGroup
                        visible={visible}
                        type={type}
                        formObj={formObj}
                        onCancel={() => setVisible(false)}
                        callBackSubmit={onSubmit}
                    />
                )}
            </PageContainer>
        </Spin>
    )

}
export default TableManager;